.. _citing:

Citing h5preserve
=================
The preferred method of citing h5preserve is to cite the `JOSS Paper`_, for
which the bibtex entry is below:

.. code-block:: bibtex

   @article{h5preserve,
     doi = {10.21105/joss.00581},
     url = {https://doi.org/10.21105/joss.00581},
     year  = {2018},
     month = {feb},
     publisher = {The Open Journal},
     volume = {3},
     number = {22},
     pages = {581},
     author = {James Tocknell},
     title = {h5preserve: Thin wrapper around h5py, inspired by camel},
     journal = {The Journal of Open Source Software}
   }

DOIs of individual releases can be found on
`Zenodo <https://doi.org/10.5281/zenodo.593007>`_, which can be cited in
addition to the JOSS paper.

We also strongly encourage citing the dependencies of h5preserve, `numpy`_ and
`h5py`_.


.. _`JOSS Paper`: http://joss.theoj.org/papers/10.21105/joss.00581/
.. _`numpy`: https://www.scipy.org/citing.html
.. _`h5py`: https://github.com/h5py/h5py/issues/743
